@@ -14,7 +14,7 @@ use Plack::Util::Accessor qw/ client sample_rate /;
 use POSIX ();
 use Time::HiRes;
 
-our $VERSION = 'v0.1.1';
+our $VERSION = 'v0.2.0';
 
 sub call {
     my ( $self, $env ) = @_;
@@ -62,7 +62,12 @@ sub call {
 
             my $h = Plack::Util::headers( $res->[1] );
 
-            if ( $h->exists('X-Sendfile') ) {    # TODO: configurable
+            my $xsendfile =
+                 $env->{'plack.xsendfile.type'}
+              || $ENV{HTTP_X_SENDFILE_TYPE}
+              || 'X-Sendfile';
+
+            if ( $h->exists($xsendfile) ) {
                 $client->increment( 'psgi.response.x-sendfile', $rate );
             }
 
@@ -111,7 +116,7 @@ Plack::Middleware::Statsd - send statistics to statsd
 
 =head1 VERSION
 
-version v0.1.1
+version v0.2.0
 
 =head1 SYNOPSIS
 
@@ -216,6 +221,13 @@ The content-length of the request, if it is specified in the header.
 This is treated as a timing rather than a counter, so that statistics
 can be saved.
 
+=item C<psgi.request.content-type.$TYPE.$SUBTYPE>
+
+A counter for the content type of request bodies is incremented, e.g.
+C<psgi.request.content-type.application.x-www-form-urlencoded>.
+
+Any modifiers in the type, e.g. C<charset>, will be ignored.
+
 =item C<psgi.response.content-length>
 
 The content-length of the response, if it is specified in the header.
@@ -228,11 +240,13 @@ can be saved.
 A counter for the content type is incremented, e.g. for a JPEG image,
 the counter C<psgi.response.content-type.image.jpeg> is incremented.
 
+Any modifiers in the type, e.g. C<charset>, will be ignored.
+
 =item C<psgi.response.status.$CODE>
 
 A counter for the HTTP status code is incremented.
 
-=item psgi.response.time
+=item C<psgi.response.time>
 
 The response time, in ms (rounded up using C<ceil>).
 
@@ -240,6 +254,11 @@ The response time, in ms (rounded up using C<ceil>).
 
 This counter is incremented when the C<X-Sendfile> header is added.
 
+The header is configured using the C<plack.xsendfile.type> environment
+key, ortherwise the C<HTTP_X_SENDFILE_TYPE> environment variable.
+
+See L<Plack::Middleware::XSendfile> for more information.
+
 =item C<psgix.harakiri>
 
 This counter is incremented when the harakiri flag is set.
@@ -247,7 +266,7 @@ This counter is incremented when the harakiri flag is set.
 =back
 
 If you want to rename these, then you will need to use a wrapper
-class.
+class for the L</client>.
 
 =head1 SEE ALSO
 
